FlowJax
===============
FlowJax is a package for creating and fitting normalising flows in Jax.

Installation
------------------------
.. code-block:: bash

    pip install flowjax


.. toctree::
   :caption: Examples
   :maxdepth: 1
   :glob:

   examples/unconditional
   examples/conditional
   examples/variational_inference
   examples/bounded
   examples/snpe

.. toctree::
   :caption: API
   :maxdepth: 1
   :glob:

   api/*

.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous
   
   faq
